# GitStats

[![Tests](https://github.com/DillonB07/GitStats/actions/workflows/pytest.yml/badge.svg)](https://github.com/DillonB07/GitStats/actions/workflows/pytest.yml)
![PyPI](https://img.shields.io/pypi/v/pygitstats?color=blue&label=PyPi&logo=pypi&logoColor=yellow)
![PyPI - Downloads](https://img.shields.io/pypi/dm/pygitstats?color=blue&label=Downloads&logo=pypi&logoColor=yellow)
![PyPI - Format](https://img.shields.io/pypi/format/pygitstats?color=blue&&label=Format&logo=pypi&logoColor=yellow)
![PyPI - Status](https://img.shields.io/pypi/status/pygitstats?color=blue&label=Status&logo=pypi&logoColor=yellow)
![PyPI - License](https://img.shields.io/pypi/l/pygitstats?color=blue&label=License&logo=pypi&logoColor=yellow)

pygitstats is a package that allows you to use the GitHub GraphQL API with ease in your Python programs.

## Installation

Anyone can use this package by installing it from PyPi via one of the following commands:

### Pip

```zsh
pip install pygitstats
```

```zsh
pip3 install pygitstats
```

```zsh
python -m pip install pygitstats
```

```zsh
python3 -m pip install pygitstats
```

### Poetry

```zsh
poetry install pygitstats
```

### Conda

```zsh
conda install pygitstats
```

### Pipenv

```zsh
pipenv install pygitstats
```

## Usage

Just import the modules you need and get started!

## License

This project is licensed under the LGPLv3 license.
